diff --git a/.github/workflows/test.yml b/.github/workflows/test.yml
index 7a4147a..8ef1da4 100644
--- a/.github/workflows/test.yml
+++ b/.github/workflows/test.yml
@@ -27,7 +27,7 @@ jobs:
fail-fast: false
matrix:
platform: [ubuntu-latest, ubuntu-20.04, macos-latest, macos-11, macos-13, windows-latest]
- postgresql_version: [10, 11, 12, 14, 15]
+ postgresql_version: [10, 11, 12, 14, 15, 16]
steps:
- name: Checkout
uses: actions/checkout@v4
diff --git a/README.md b/README.md
index ded9899..d4db46e 100644
--- a/README.md
+++ b/README.md
@@ -17,7 +17,7 @@ This Github action installs PostgreSQL on the GitHub actions runner and verifies
- name: Setup PostgreSQL
uses: tj-actions/install-postgresql@v2
with:
- postgresql-version: 15
+ postgresql-version: 16
```
> NOTE: This updates the installed PostgreSQL version with the specified version and updates the PATH.
@@ -28,7 +28,7 @@ This Github action installs PostgreSQL on the GitHub actions runner and verifies
| INPUT | TYPE | REQUIRED | DEFAULT | DESCRIPTION |
|----------------------------------------------------------------------------------------|--------|----------|---------|-------------------------------|
-| [postgresql-version](#input_postgresql-version) | string | true | | Version of PostgreSQL. e.g 15 |
+| [postgresql-version](#input_postgresql-version) | string | true | | Version of PostgreSQL. e.g 16 |
diff --git a/action.yml b/action.yml
index 556ed82..ce6a7d4 100644
--- a/action.yml
+++ b/action.yml
@@ -3,7 +3,7 @@ description: Install PostgreSQL on the GitHub actions runner and verify the inst
author: tj-actions
inputs:
postgresql-version:
- description: 'Version of PostgreSQL. e.g 15'
+ description: 'Version of PostgreSQL. e.g 16'
required: true
runs:
diff --git a/entrypoint.sh b/entrypoint.sh
index 84d4ebf..16bac3f 100755
--- a/entrypoint.sh
+++ b/entrypoint.sh
@@ -12,9 +12,9 @@ if ! [[ "$INPUT_POSTGRESQL_VERSION" =~ ^[0-9]+$ ]]; then
exit 1
fi
-# Check if the input is between 10 and 15 (inclusive)
-if (( INPUT_POSTGRESQL_VERSION < 10 || INPUT_POSTGRESQL_VERSION > 15 )); then
- echo "Error: $INPUT_POSTGRESQL_VERSION is not between 10 and 15 (inclusive)."
+# Check if the input is between 10 and 16 (inclusive)
+if (( INPUT_POSTGRESQL_VERSION < 10 || INPUT_POSTGRESQL_VERSION > 16 )); then
+ echo "Error: $INPUT_POSTGRESQL_VERSION is not between 10 and 16 (inclusive)."
exit 1
fi